%
%  this function creates the bracket
%
function  [ax, bx, cx] = mnbrak1(ax,bx,iprint,key);
%
%  This function creates brackets for a 1-D problem
%
%
%  This code is based on the "mnbrak" code of 
%  Press, W.H.,  Flannery, B.P., Teukolsky, S.A., Vetterling, W.T.
%  "Numerical Recipes", Cambridge University Pres, Cambridge, 1986, p. 281-282.
%  
%  Fortran translated to Matlab by David Keffer
%  Department of Chemical Engineering, University of Tennessee
%  May,1999
%
%  This function calls syseqninput.m
%
gold = 1.618034;
glimit = 100.0;
tiny=1.e-20;
fa = fnctn_filter(ax,key);
fb = fnctn_filter(bx,key);
if (fb > fa)
   dum = ax;
   ax = bx;
   bx = dum;
   dum = fb;
   fb = fa;
   fa = dum;
end
%
% first guess for c
%
cx = bx+gold*(bx-ax);
fc = fnctn_filter(cx,key);
%
%  main loop
%
while (fb >= fc) 
   %
   % try parabolic fit
   %
   r = (bx - ax)*(fb-fc);
   q = (bx-cx)*(fb-fa);
   if (abs(r-q) > 1.0e-12)		% line I added 
   	u = bx - ( (bx-cx)*q - (bx-ax)*r ) / ( 2*sign(max(abs(q-r),tiny)*(q-r))*abs(q-r) );
   else								% line I added 
      u = 0.0;						% line I added 
   end								% line I added 
   ulim = bx + glimit*(cx - bx);
	if  ( (bx -u)*(u-cx) > 0 )
      fu = fnctn_filter(u,key);
      if ( fu < fc )
         ax = bx;
         fa = fb;
         bx = u;
         fb = fu;
         return;
      elseif (fu > fb )
         cx = u;
         fc = fu;
         return;
      end
      %
      % parabolic fit was no good, try default magnification
      %
      u = cx+gold*(cx-bx);
      fu = fnctn_filter(u,key); 
   elseif ( (cx-u)*(u-ulim) > 0 )
      fu = fnctn_filter(u,key); 
      if ( fu < fc ) 
         bx = cx;
         cx = u;
         u = cx + gold*(cx-bx);
         fb = fc;
         fc = fu;
         fu = fnctn_filter(u,key);
      end
   elseif ( (u-ulim)*(ulim-cx) >= 0) 
      u=ulim;
      fu = fnctn_filter(u,key);
   else
      u = cx + gold*(cx -bx);
      fu = fnctn_filter(u,key);
   end
   ax = bx;
   bx = cx;
   cx = u;
   fa = fb;
   fb = fc;
   fc = fu;
end


         
      



function f = fnctn_filter(x,key);
global pcom xcom ncom
for j = 1:1:ncom
   xt(j) = pcom(j) + x*xcom(j);   
end
f = funkeval(xt);
